@@ -17,7 +17,8 @@ get '/ajax/content/device/vlans' => require_login sub {
 
     my $device = schema('netdisco')->resultset('Device')
       ->search_for_device($q) or send_error('Bad device', 400);
-    my @results = $device->vlans->search( {}, { order_by => 'vlan' } )->hri->all;
+    my @results = $device->vlans->search(
+      { vlan => { '>' => 0 } }, { order_by => 'vlan' } )->hri->all;
 
     return unless scalar @results;
 
